@@ -287,6 +287,31 @@ migrate_genum (GConfClient *client,
     gconf_value_free (value);
 }
 
+static void
+migrate_palette (GConfClient *client,
+                 const char *gconf_path,
+                 GSettings *settings)
+{
+  GConfValue *value;
+  char *key;
+  char **strv;
+
+  key = gconf_concat_dir_and_key (gconf_path, KEY_PALETTE);
+  value = gconf_client_get_without_default (client, key, NULL);
+  g_free (key);
+
+  if (value != NULL &&
+      value->type == GCONF_VALUE_STRING) {
+    strv = g_strsplit (gconf_value_get_string (value), ":", -1);
+    g_settings_set_strv (settings, TERMINAL_PROFILE_PALETTE_KEY,
+                         (const char * const *) strv);
+    g_strfreev (strv);
+  }
+
+  if (value)
+    gconf_value_free (value);
+}
+
 static gboolean
 migrate_global_prefs (GSettings *settings,
                       GError **error)
@@ -423,8 +448,7 @@ migrate_profile (TerminalSettingsList *list,
   migrate_genum (client, path, KEY_CURSOR_SHAPE,
                  settings, TERMINAL_PROFILE_CURSOR_SHAPE_KEY,
                  VTE_TYPE_TERMINAL_CURSOR_SHAPE);
-  migrate_string_list (client, path, KEY_PALETTE,
-                       settings, TERMINAL_PROFILE_PALETTE_KEY);
+  migrate_palette (client, path, settings);
   migrate_string (client, path, KEY_FONT,
                   settings, TERMINAL_PROFILE_FONT_KEY);
   migrate_enum (client, path, KEY_BACKSPACE_BINDING, erase_binding_pairs,
@@ -599,6 +623,7 @@ main (int argc,
   GOptionContext *context;
   GError *error = NULL;
   GSettings *global_settings;
+  int rv = EXIT_SUCCESS;
 
   setlocale (LC_ALL, "");
 
@@ -621,6 +646,16 @@ main (int argc,
 
   global_settings = g_settings_new (TERMINAL_SETTING_SCHEMA);
 
+  if (clean) {
+    if (!force) {
+      g_printerr ("--clean requires --force\n");
+      rv = EXIT_FAILURE;
+      goto out;
+    }
+
+    do_clean ();
+  }
+ 
   if (g_settings_get_uint (global_settings, TERMINAL_SETTING_SCHEMA_VERSION) >= TERMINAL_SCHEMA_VERSION) {
     if (verbose)
       g_printerr ("Already migrated.\n");
@@ -628,9 +663,6 @@ main (int argc,
       goto out;
   }
 
-  if (clean)
-    do_clean ();
-
   if (!migrate (global_settings, &error)) {
     g_printerr ("Error: %s\n", error->message);
     g_error_free (error);
@@ -650,5 +682,5 @@ main (int argc,
  out:
   g_object_unref (global_settings);
 
-  return EXIT_SUCCESS;
+  return rv;
 }
